Convert to best of numeric or character.
Convert data.frame columns to best of numeric or character.
as.best(x, ...)# S3 method for data.frame
as.best(x, prefix = "#", ...)
data.frame
data.frame
passed arguments
character to prepend to values in mixed numeric/character columns
as.best(data.frame): data.frame method
Converts to numeric if doing so creates no new NA; otherwise to character.
Converts columns to numeric if doing so creates no new NA; otherwise to character. Number-like columns that are nevertheless character are prefixed by default to make this explicit when viewing only a few rows.
Other util:
%contains%(),
as.best.default(),
enclose(),
locf(),
padded(),
parens(),
pool(),
runhead(),
text2decimal()
Other util:
%contains%(),
as.best.default(),
enclose(),
locf(),
padded(),
parens(),
pool(),
runhead(),
text2decimal()