Convert vector to best of numeric or character.
# S3 method for default
as.best(x, prefix = "", na.strings = c(".", "NA", ""), ...)default
prefix for viewing numerics
strings that should be treated as NA
ignored
Converts vector to numeric if doing so creates no new NA; otherwise to character. Number-like vectors that are nevertheless character are prefixed by default to make this explicit when viewing only a few rows.
Other util:
%contains%(),
as.best(),
enclose(),
locf(),
padded(),
parens(),
pool(),
runhead(),
text2decimal()